@@ -370,30 +370,39 @@ class Controller:
         self._tools_enabled = enabled
 
     # Rotate camera view according defined angle
-    def rotateView(self, coordinate: str = "x", angle: int = 0) -> None:
+    def setCameraRotation(self, coordinate: str = "x", angle: int = 0) -> None:
         camera = self._scene.getActiveCamera()
         if not camera:
             return
-        self._camera_tool.setOrigin(Vector(0, 100, 0)) #type: ignore
+        camera.setZoomFactor(camera.getDefaultZoomFactor())
+        self._camera_tool.setOrigin(Vector(0, 100, 0))  # type: ignore
         if coordinate == "home":
-            camera.setPosition(Vector(0, 0, 700))
-            camera.setPerspective(True)
-            camera.lookAt(Vector(0, 100, 100))
-            self._camera_tool.rotateCam(0, 0) #type: ignore
+            camera.setPosition(Vector(0, 100, 700))
+            camera.lookAt(Vector(0, 100, 0))
+            self._camera_tool.rotateCamera(0, 0)  # type: ignore
         elif coordinate == "3d":
             camera.setPosition(Vector(-750, 600, 700))
-            camera.setPerspective(True)
             camera.lookAt(Vector(0, 100, 100))
-            self._camera_tool.rotateCam(0, 0) #type: ignore
-
+            self._camera_tool.rotateCamera(0, 0)  # type: ignore
         else:
             # for comparison is == used, because might not store them at the same location
             # https://stackoverflow.com/questions/1504717/why-does-comparing-strings-in-python-using-either-or-is-sometimes-produce
-            camera.setPosition(Vector(0, 0, 700))
-            camera.setPerspective(True)
-            camera.lookAt(Vector(0, 100, 0))
 
             if coordinate == "x":
-                self._camera_tool.rotateCam(angle, 0) #type: ignore
+                camera.setPosition(Vector(0, 100, 700))
+                camera.lookAt(Vector(0, 100, 0))
+                self._camera_tool.rotateCamera(angle, 0)  # type: ignore
             elif coordinate == "y":
-                self._camera_tool.rotateCam(0, angle) #type: ignore
\ No newline at end of file
+                if angle == 90:
+                    # Prepare the camera for top view, so no rotation has to be applied after setting the top view.
+                    camera.setPosition(Vector(0, 100, 100))
+                    camera.lookAt(Vector(0, 100, 0))
+                    self._camera_tool.rotateCamera(90, 0)  # type: ignore
+                    # Actually set the top view.
+                    camera.setPosition(Vector(0, 800, 1))
+                    camera.lookAt(Vector(0, 100, 1))
+                    # Note the absence of rotation at the end!
+                else:
+                    camera.setPosition(Vector(0, 100, 700))
+                    camera.lookAt(Vector(0, 100, 0))
+                    self._camera_tool.rotateCamera(0, angle)  # type: ignore
