@@ -1,5 +1,6 @@
 # Copyright (c) 2016 Ultimaker B.V.
-# Uranium is released under the terms of the AGPLv3 or higher.
+# Uranium is released under the terms of the LGPLv3 or higher.
+from typing import Union, List
 
 import numpy
 from copy import deepcopy
@@ -9,7 +10,7 @@ from copy import deepcopy
 #   If the array is already immutable then it just returns it.
 #   \param nda \type{numpy.ndarray} the array to copy. May be a list
 #   \return \type{numpy.ndarray} an immutable narray
-def immutableNDArray(nda):
+def immutableNDArray(nda: Union[List, numpy.array]) -> numpy.array:
     if nda is None:
         return None
 
